{*
 *******************************************************************************
 *
 *  Copyright 2025 RIEGL Laser Measurement Systems
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  SPDX-License-Identifier: Apache-2.0
 *
 *******************************************************************************
 *}
{*!
 *******************************************************************************
 *
 * \author RIEGL LMS GmbH, Austria
 * \brief  Description of RIEGL RDB 2 database file contents
 *
 *  NOTE: All information in this file is preliminary, since the
 *        definition of the database schemas is not yet complete.
 *
 *******************************************************************************
 *}

unit riegl.rdb.default.schema;

{$WRITEABLECONST ON} // see section "initialization"

interface

// File schema version
const
  RDB_SCHEMA_VERSION = 'f274d50d';
  RDB_SCHEMA_DATE = '2023-11-30';

// Schema for ".avg.fwa" files
const
  RDB_SCHEMA_RIEGL_AVG_FWA : System.String = (''
    + '{"identifier":"avg.fwa","attributes":["riegl.id*","riegl.amplitude","r'
    + 'iegl.gain","riegl.raw_range","riegl.wfm_echo_time_offset","riegl.wfm_s'
    + 'bl_id","riegl.deviation?","riegl.pulse_width?"],"metadata":[],"extensi'
    + 'on":"avg.fwa"}'
  );

// Schema for ".avg.sbx" files
const
  RDB_SCHEMA_RIEGL_AVG_SBX : System.String = (''
    + '{"identifier":"avg.sbx","attributes":["riegl.id*","riegl.wfm_sbl_chann'
    + 'el","riegl.wfm_sbl_mean","riegl.wfm_sbl_std_dev","riegl.wfm_sbl_time_o'
    + 'ffset","riegl.wfm_sda_first","riegl.wfm_sda_count"],"metadata":[],"ext'
    + 'ension":"avg.sbx"}'
  );

// Schema for ".avg.sidx" files
const
  RDB_SCHEMA_RIEGL_AVG_SIDX : System.String = (''
    + '{"identifier":"avg.sidx","attributes":["riegl.id","riegl.shot_timestam'
    + 'p_hr*","riegl.wfm_sbl_first","riegl.wfm_sbl_count","riegl.echo_first?"'
    + ',"riegl.echo_count?"],"metadata":["riegl.shot_info","riegl.waveform_in'
    + 'fo","riegl.echo_info?","riegl.waveform_averaging_settings"],"extension'
    + '":"avg.sidx"}'
  );

// Schema for ".avg.sp{C}" files
const
  RDB_SCHEMA_RIEGL_AVG_SPC : System.String = (''
    + '{"identifier":"avg.sp{C}","attributes":["riegl.id*","riegl.wfm_sample_'
    + 'value"],"metadata":[],"extension":"avg.sp{C}"}'
  );

// Schema for ".cpx" files
const
  RDB_SCHEMA_RIEGL_CPX : System.String = (''
    + '{"identifier":"cpx","attributes":["riegl.id","riegl.xyz*","riegl.xyz_a'
    + 'ccuracies","riegl.control_object_type","riegl.zenith_vector","riegl.us'
    + 'ed_for_adjustment","riegl.acquisition_date?","riegl.cp_surface_inclina'
    + 'tion_angle","riegl.cp_surface_inclination_tolerance_angle","riegl.cp_s'
    + 'earch_radius?","riegl.cp_maximum_distance?","riegl.import_line_number"'
    + '],"metadata":["riegl.geo_tag","riegl.control_object_catalog","riegl.it'
    + 'em_names","riegl.imported_files"],"extension":"cpx"}'
  );

// Schema for ".doix" files
const
  RDB_SCHEMA_RIEGL_DOIX : System.String = (''
    + '{"identifier":"doix","attributes":["riegl.id","riegl.shot_origin","rie'
    + 'gl.shot_direction*","riegl.scan_line_index","riegl.shot_index_line"],"'
    + 'metadata":[],"extension":"doix"}'
  );

// Schema for ".eifx" files
const
  RDB_SCHEMA_RIEGL_EIFX : System.String = (''
    + '{"identifier":"eifx","attributes":["riegl.id","riegl.event_timestamp*"'
    + ',"riegl.event_index?","riegl.event_pulse_width?","riegl.event_fake_pul'
    + 'se?","riegl.raw_line_angle?","riegl.raw_frame_angle?"],"metadata":["ri'
    + 'egl.device?","riegl.time_base","riegl.ttip_configuration?"],"extension'
    + '":"eifx"}'
  );

// Schema for ".epfx" files
const
  RDB_SCHEMA_RIEGL_EPFX : System.String = (''
    + '{"identifier":"epfx","attributes":["riegl.id","riegl.event_timestamp*"'
    + ',"riegl.event_index?","riegl.event_pulse_width?","riegl.event_fake_pul'
    + 'se?","riegl.raw_line_angle?","riegl.raw_frame_angle?","riegl.xyz","rie'
    + 'gl.model_cs_axis_x","riegl.model_cs_axis_y","riegl.model_cs_axis_z"],"'
    + 'metadata":["riegl.device?","riegl.geo_tag","riegl.time_base","riegl.tt'
    + 'ip_configuration?"],"extension":"epfx"}'
  );

// Schema for ".fwa" files
const
  RDB_SCHEMA_RIEGL_FWA : System.String = (''
    + '{"identifier":"fwa","attributes":["riegl.id*","riegl.amplitude","riegl'
    + '.gain","riegl.raw_range","riegl.wfm_echo_time_offset","riegl.wfm_sbl_i'
    + 'd","riegl.deviation?","riegl.pulse_width?","riegl.extinction?","riegl.'
    + 'svb_amplitude_volumetric?","riegl.svb_surface?","riegl.svb_bottom?","r'
    + 'iegl.svb_path_length?"],"metadata":[],"extension":"fwa"}'
  );

// Schema for ".llhx" files
const
  RDB_SCHEMA_RIEGL_LLHX : System.String = (''
    + '{"identifier":"llhx","attributes":["riegl.pof_latitude","riegl.pof_lon'
    + 'gitude","riegl.pof_height","riegl.pof_timestamp*","riegl.pof_accuracy_'
    + 'north","riegl.pof_accuracy_east","riegl.pof_accuracy_down","riegl.pof_'
    + 'pdop","riegl.pof_hdop","riegl.pof_vdop","riegl.pof_age_of_corrections"'
    + ',"riegl.pof_baseline_length","riegl.pof_solution_gnss","riegl.pof_sate'
    + 'llites_gnss","riegl.id"],"metadata":["riegl.device?","riegl.geo_tag","'
    + 'riegl.time_base"],"extension":"llhx"}'
  );

// Schema for ".mpx" files
const
  RDB_SCHEMA_RIEGL_MPX : System.String = (''
    + '{"identifier":"mpx","attributes":["riegl.id","riegl.xy_map*","riegl.am'
    + 'plitude","riegl.reflectance","riegl.deviation","riegl.timestamp_min?",'
    + '"riegl.timestamp_max?","riegl.point_count","riegl.point_count_grid_cel'
    + 'l","riegl.pixel_linear_sums?","riegl.pixel_square_sums?","riegl.height'
    + '_min","riegl.height_max","riegl.height_mean","riegl.height_center","ri'
    + 'egl.surface_normal","riegl.pca_thickness","riegl.std_dev","riegl.voxel'
    + '_count"],"metadata":["riegl.geo_tag","riegl.pixel_info","riegl.time_ba'
    + 'se?"],"extension":"mpx"}'
  );

// Schema for ".mtch" files
const
  RDB_SCHEMA_RIEGL_MTCH : System.String = (''
    + '{"identifier":"mtch","attributes":["riegl.xyz*","riegl.plane_reference'
    + 's","riegl.plane_patch_distance","riegl.plane_patch_lateral_distance","'
    + 'riegl.plane_patch_link_vector","riegl.id"],"metadata":["riegl.plane_pa'
    + 'tch_matching"],"extension":"mtch"}'
  );

// Schema for ".mvx" files
const
  RDB_SCHEMA_RIEGL_MVX : System.String = (''
    + '{"identifier":"mvx","attributes":["riegl.id","riegl.xyz_map*","riegl.a'
    + 'mplitude","riegl.reflectance","riegl.deviation","riegl.timestamp_min?"'
    + ',"riegl.timestamp_max?","riegl.point_count","riegl.shape_id","riegl.co'
    + 'variances?","riegl.pca_axis_min","riegl.pca_axis_max","riegl.pca_exten'
    + 'ts","riegl.std_dev","riegl.voxel_collapsed"],"metadata":["riegl.geo_ta'
    + 'g","riegl.time_base?","riegl.voxel_info"],"extension":"mvx"}'
  );

// Schema for ".obsx" files
const
  RDB_SCHEMA_RIEGL_OBSX : System.String = (''
    + '{"identifier":"obsx","attributes":["riegl.xyz","riegl.surface_normal",'
    + '"riegl.plane_slope_class?","riegl.id*","riegl.sda1_plane_patch_one","r'
    + 'iegl.sda1_plane_patch_two","riegl.sda1_source_file_one","riegl.sda1_so'
    + 'urce_file_two"],"metadata":["riegl.geo_tag","riegl.plane_slope_class_i'
    + 'nfo?","riegl.pointcloud_info","riegl.sda1_source_files"],"extension":"'
    + 'obsx"}'
  );

// Schema for ".opefx" files
const
  RDB_SCHEMA_RIEGL_OPEFX : System.String = (''
    + '{"identifier":"opefx","attributes":["riegl.id","riegl.xyz*","riegl.xyz'
    + '_accuracies?","riegl.surface_normal","riegl.plane_up","riegl.point_cou'
    + 'nt","riegl.std_dev","riegl.plane_width","riegl.plane_height","riegl.pl'
    + 'ane_confidence_normal","riegl.model_fit_quality?","riegl.used_for_adju'
    + 'stment","riegl.xyz_socs","riegl.timestamp","riegl.mirror_facet","riegl'
    + '.platform_rpy_ROCS_NED","riegl.platform_drpy_ROCS_NED","riegl.platform'
    + '_xyz_ROCS_ENU","riegl.platform_dxyz_ROCS_ENU","riegl.sda.shift_vector"'
    + ',"riegl.raw_range","riegl.raw_frame_angle","riegl.raw_line_angle","rie'
    + 'gl.reference_object_id"],"metadata":["riegl.device","riegl.device_geom'
    + 'etry","riegl.geo_tag","riegl.georeferencing_parameters","riegl.scan_pa'
    + 'ttern?","riegl.time_base","riegl.item_names","riegl.control_object_ref'
    + 'erence_file"],"extension":"opefx"}'
  );

// Schema for ".opp" files
const
  RDB_SCHEMA_RIEGL_OPP : System.String = (''
    + '{"identifier":"opp","attributes":["riegl.id","riegl.xyz*","riegl.xyz_a'
    + 'ccuracies?","riegl.surface_normal","riegl.plane_up","riegl.point_count'
    + '","riegl.std_dev","riegl.plane_width","riegl.plane_height","riegl.plan'
    + 'e_confidence_normal","riegl.model_fit_quality?","riegl.used_for_adjust'
    + 'ment","riegl.xyz_socs","riegl.timestamp","riegl.mirror_facet","riegl.p'
    + 'latform_rpy_ROCS_NED","riegl.platform_drpy_ROCS_NED","riegl.platform_x'
    + 'yz_ROCS_ENU","riegl.platform_dxyz_ROCS_ENU","riegl.sda.shift_vector","'
    + 'riegl.raw_range","riegl.raw_frame_angle","riegl.raw_line_angle","riegl'
    + '.reference_object_id"],"metadata":["riegl.device","riegl.device_geomet'
    + 'ry","riegl.geo_tag","riegl.georeferencing_parameters","riegl.scan_patt'
    + 'ern?","riegl.time_base","riegl.item_names","riegl.control_object_refer'
    + 'ence_file"],"extension":"opp"}'
  );

// Schema for ".opx" files
const
  RDB_SCHEMA_RIEGL_OPX : System.String = (''
    + '{"identifier":"opx","attributes":["riegl.id","riegl.xyz*","riegl.contr'
    + 'ol_object_type","riegl.model_cs_axis_x?","riegl.model_cs_axis_y?","rie'
    + 'gl.model_cs_axis_z?","riegl.model_fit_quality?","riegl.obs_confidence_'
    + 'xy?","riegl.obs_confidence_z?","riegl.obs_signal_confidence_rot?","rie'
    + 'gl.obs_confidence_range?","riegl.obs_confidence_theta?","riegl.obs_con'
    + 'fidence_phi?","riegl.point_count?","riegl.used_for_adjustment","riegl.'
    + 'xyz_socs","riegl.timestamp","riegl.mirror_facet","riegl.platform_rpy_R'
    + 'OCS_NED","riegl.platform_drpy_ROCS_NED","riegl.platform_xyz_ROCS_ENU",'
    + '"riegl.platform_dxyz_ROCS_ENU","riegl.sda.shift_vector","riegl.raw_ran'
    + 'ge","riegl.raw_frame_angle","riegl.raw_line_angle","riegl.reference_ob'
    + 'ject_id"],"metadata":["riegl.device","riegl.device_geometry","riegl.ge'
    + 'o_tag","riegl.georeferencing_parameters","riegl.scan_pattern?","riegl.'
    + 'time_base","riegl.control_object_catalog","riegl.item_names","riegl.co'
    + 'ntrol_object_reference_file"],"extension":"opx"}'
  );

// Schema for ".owp" files
const
  RDB_SCHEMA_RIEGL_OWP : System.String = (''
    + '{"identifier":"owp","attributes":["riegl.id*","riegl.raw_range","riegl'
    + '.amplitude","riegl.deviation","riegl.gain"],"metadata":[],"extension":'
    + '"owp"}'
  );

// Schema for ".pefx" files
const
  RDB_SCHEMA_RIEGL_PEFX : System.String = (''
    + '{"identifier":"pefx","attributes":["riegl.id","riegl.xyz*","riegl.xyz_'
    + 'accuracies?","riegl.surface_normal","riegl.plane_up","riegl.std_dev","'
    + 'riegl.plane_confidence_normal","riegl.plane_width","riegl.plane_height'
    + '","riegl.vertex_first","riegl.vertex_count","riegl.used_for_adjustment'
    + '","riegl.acquisition_date?","riegl.import_line_number","riegl.import_l'
    + 'ine_count"],"metadata":["riegl.geo_tag","riegl.vertex_info","riegl.ite'
    + 'm_names","riegl.imported_files"],"extension":"pefx"}'
  );

// Schema for ".pofx" files
const
  RDB_SCHEMA_RIEGL_PROJECT_POFX : System.String = (''
    + '{"identifier":"project.pofx","attributes":["riegl.id","riegl.pof_times'
    + 'tamp*","riegl.pof_latitude","riegl.pof_longitude","riegl.pof_height","'
    + 'riegl.pof_roll","riegl.pof_pitch","riegl.pof_yaw","riegl.pof_path_leng'
    + 'th?"],"metadata":["riegl.device?","riegl.time_base","riegl.trajectory_'
    + 'info"],"extension":"pofx"}'
  );

// Schema for ".pofx" files
const
  RDB_SCHEMA_RIEGL_SCAN_POFX : System.String = (''
    + '{"identifier":"scan.pofx","attributes":["riegl.id","riegl.pof_timestam'
    + 'p*","riegl.pof_latitude","riegl.pof_longitude","riegl.pof_height","rie'
    + 'gl.pof_roll","riegl.pof_pitch","riegl.pof_yaw","riegl.pof_path_length?'
    + '","riegl.pof_xyz","riegl.pof_roll_ned","riegl.pof_pitch_ned","riegl.po'
    + 'f_yaw_ned"],"metadata":["riegl.device?","riegl.time_base","riegl.geo_t'
    + 'ag","riegl.trajectory_info"],"extension":"pofx"}'
  );

// Schema for ".poqx" files
const
  RDB_SCHEMA_RIEGL_PROJECT_POQX : System.String = (''
    + '{"identifier":"project.poqx","attributes":["riegl.id","riegl.pof_times'
    + 'tamp*","riegl.pof_accuracy_north","riegl.pof_accuracy_east","riegl.pof'
    + '_accuracy_down","riegl.pof_accuracy_roll","riegl.pof_accuracy_pitch","'
    + 'riegl.pof_accuracy_yaw","riegl.pof_path_length?","riegl.pof_pdop","rie'
    + 'gl.pof_satellites_gnss?","riegl.pof_satellites_gps?","riegl.pof_satell'
    + 'ites_glonass?","riegl.pof_satellites_beidou?","riegl.pof_satellites_ga'
    + 'lileo?","riegl.pof_satellites_qzss?"],"metadata":["riegl.time_base","r'
    + 'iegl.trajectory_info"],"extension":"poqx"}'
  );

// Schema for ".poqx" files
const
  RDB_SCHEMA_RIEGL_SCAN_POQX : System.String = (''
    + '{"identifier":"scan.poqx","attributes":["riegl.id","riegl.pof_timestam'
    + 'p*","riegl.pof_accuracy_north","riegl.pof_accuracy_east","riegl.pof_ac'
    + 'curacy_down","riegl.pof_accuracy_roll","riegl.pof_accuracy_pitch","rie'
    + 'gl.pof_accuracy_yaw","riegl.pof_path_length?","riegl.pof_pdop","riegl.'
    + 'pof_satellites_gnss?","riegl.pof_satellites_gps?","riegl.pof_satellite'
    + 's_glonass?","riegl.pof_satellites_beidou?","riegl.pof_satellites_galil'
    + 'eo?","riegl.pof_satellites_qzss?"],"metadata":["riegl.time_base","rieg'
    + 'l.trajectory_info"],"extension":"poqx"}'
  );

// Schema for ".ppx" files
const
  RDB_SCHEMA_RIEGL_PPX : System.String = (''
    + '{"identifier":"ppx","attributes":["riegl.id","riegl.pps_timestamp_inte'
    + 'rn*","riegl.pps_timestamp_extern"],"metadata":["riegl.device","riegl.t'
    + 'ime_base"],"extension":"ppx"}'
  );

// Schema for ".ptch" files
const
  RDB_SCHEMA_RIEGL_PROJECT_PTCH : System.String = (''
    + '{"identifier":"project.ptch","attributes":["riegl.xyz*","riegl.surface'
    + '_normal","riegl.plane_up","riegl.reflectance?","riegl.point_count","ri'
    + 'egl.std_dev","riegl.plane_width","riegl.plane_height","riegl.plane_cou'
    + 'nt","riegl.covariances","riegl.id"],"metadata":["riegl.device","riegl.'
    + 'geo_tag?","riegl.scan_pattern?","riegl.time_base?","riegl.plane_patch_'
    + 'statistics?"],"extension":"ptch"}'
  );

// Schema for ".ptch" files
const
  RDB_SCHEMA_RIEGL_SCAN_PTCH : System.String = (''
    + '{"identifier":"scan.ptch","attributes":["riegl.xyz*","riegl.xyz_socs",'
    + '"riegl.direction?","riegl.direction_medium?","riegl.direction_coarse?"'
    + ',"riegl.surface_normal","riegl.plane_up","riegl.timestamp","riegl.refl'
    + 'ectance?","riegl.point_count","riegl.std_dev","riegl.plane_width","rie'
    + 'gl.plane_height","riegl.plane_count","riegl.mirror_facet","riegl.covar'
    + 'iances","riegl.id","riegl.plane_slope_class?","riegl.plane_occupancy",'
    + '"riegl.plane_confidence_normal","riegl.plane_cog_link","riegl.match_co'
    + 'unt","riegl.platform_rpy_ROCS_NED","riegl.platform_xyz_ROCS_ENU","rieg'
    + 'l.platform_drpy_ROCS_NED","riegl.platform_dxyz_ROCS_ENU","riegl.sda.sh'
    + 'ift_vector","riegl.raw_range","riegl.raw_frame_angle","riegl.raw_line_'
    + 'angle"],"metadata":["riegl.device","riegl.device_geometry","riegl.geo_'
    + 'tag","riegl.georeferencing_parameters","riegl.scan_pattern?","riegl.ti'
    + 'me_base","riegl.plane_patch_statistics?","riegl.plane_slope_class_info'
    + '?"],"extension":"ptch"}'
  );

// Schema for ".ptch" files
const
  RDB_SCHEMA_RIEGL_SCANPOS_PTCH : System.String = (''
    + '{"identifier":"scanpos.ptch","attributes":["riegl.xyz*","riegl.surface'
    + '_normal","riegl.plane_up","riegl.reflectance?","riegl.point_count","ri'
    + 'egl.std_dev","riegl.plane_width","riegl.plane_height","riegl.plane_cou'
    + 'nt","riegl.covariances","riegl.id"],"metadata":["riegl.device","riegl.'
    + 'geo_tag?","riegl.scan_pattern?","riegl.time_base?","riegl.plane_patch_'
    + 'statistics?"],"extension":"ptch"}'
  );

// Schema for ".rdbx" files
const
  RDB_SCHEMA_RIEGL_RDBX : System.String = (''
    + '{"identifier":"rdbx","attributes":["riegl.id","riegl.timestamp","riegl'
    + '.xyz*","riegl.xyz_socs","riegl.direction_medium?","riegl.direction?","'
    + 'riegl.amplitude","riegl.reflectance?","riegl.deviation?","riegl.pulse_'
    + 'width?","riegl.target_index","riegl.target_count","riegl.mirror_facet?'
    + '","riegl.scan_segment?","riegl.mta_uncertain_point?","riegl.mta_zone?"'
    + ',"riegl.window_echo_impact_corrected?","riegl.dyntrig_uncertain_point?'
    + '","riegl.rgba?","riegl.class?","riegl.start_of_scan_line?","riegl.end_'
    + 'of_scan_line?","riegl.source_indicator?","riegl.fwa?","riegl.waveform_'
    + 'available?","riegl.wfm_sbl_id?","riegl.wfm_echo_time_offset?","riegl.s'
    + 'can_angle","riegl.scan_direction","riegl.source_index?","riegl.scan_li'
    + 'ne_index?","riegl.shot_index_line?","riegl.hydro_intersection_point?",'
    + '"riegl.hydro_intersection_normal?","riegl.extinction?","riegl.svb_ampl'
    + 'itude_volumetric?","riegl.svb_surface?","riegl.svb_bottom?","riegl.svb'
    + '_path_length?"],"metadata":["riegl.atmosphere","riegl.beam_geometry","'
    + 'riegl.device_geometry","riegl.device","riegl.gaussian_decomposition?",'
    + '"riegl.exponential_decomposition?","riegl.geo_tag","riegl.georeferenci'
    + 'ng_parameters","riegl.mta_settings?","riegl.near_range_correction?","r'
    + 'iegl.noise_estimates?","riegl.angular_notch_filter?","riegl.notch_filt'
    + 'er?","riegl.pointcloud_info?","riegl.pulse_position_modulation?","rieg'
    + 'l.range_statistics?","riegl.receiver_internals?","riegl.reflectance_ca'
    + 'lculation?","riegl.reflectance_correction?","riegl.scan_pattern","rieg'
    + 'l.time_base","riegl.waveform_settings?","riegl.window_analysis?","rieg'
    + 'l.window_echo_correction?"],"extension":"rdbx"}'
  );

// Schema for ".rmvx" files
const
  RDB_SCHEMA_RIEGL_RMVX : System.String = (''
    + '{"identifier":"rmvx","attributes":["riegl.id","riegl.voxel_index*","ri'
    + 'egl.amplitude","riegl.reflectance","riegl.deviation","riegl.direction_'
    + 'medium","riegl.point_count","riegl.voxel_linear_sums","riegl.voxel_squ'
    + 'are_sums","riegl.timestamp_min?","riegl.timestamp_max?"],"metadata":["'
    + 'riegl.geo_tag","riegl.voxel_info","riegl.time_base?"],"extension":"rmv'
    + 'x"}'
  );

// Schema for ".s10x" files
const
  RDB_SCHEMA_RIEGL_S10X : System.String = (''
    + '{"identifier":"s10x","attributes":["riegl.id","riegl.timestamp*","rieg'
    + 'l.frame_angle_coarse","riegl.gyroscope_raw","riegl.accelerometer_raw",'
    + '"riegl.magnetic_field_sensor_raw","riegl.gyroscope","riegl.acceleromet'
    + 'er","riegl.magnetic_field_sensor","riegl.barometric_height_amsl","rieg'
    + 'l.temperature","riegl.line_scan_active","riegl.frame_scan_active","rie'
    + 'gl.data_acquisition_active"],"metadata":["riegl.time_base","riegl.devi'
    + 'ce?","riegl.pose_sensors"],"extension":"s10x"}'
  );

// Schema for ".sbx" files
const
  RDB_SCHEMA_RIEGL_SBX : System.String = (''
    + '{"identifier":"sbx","attributes":["riegl.id*","riegl.wfm_sbl_channel",'
    + '"riegl.wfm_sbl_mean","riegl.wfm_sbl_std_dev","riegl.wfm_sbl_time_offse'
    + 't","riegl.wfm_sda_first","riegl.wfm_sda_count"],"metadata":[],"extensi'
    + 'on":"sbx"}'
  );

// Schema for ".sdcx" files
const
  RDB_SCHEMA_RIEGL_SDCX : System.String = (''
    + '{"identifier":"sdcx","attributes":["riegl.id","riegl.timestamp*","rieg'
    + 'l.xyz","riegl.amplitude","riegl.reflectance?","riegl.deviation?","rieg'
    + 'l.pulse_width?","riegl.target_index","riegl.target_count","riegl.mirro'
    + 'r_facet?","riegl.scan_segment?","riegl.mta_uncertain_point?","riegl.mt'
    + 'a_zone?","riegl.window_echo_impact_corrected?","riegl.dyntrig_uncertai'
    + 'n_point?","riegl.class?","riegl.start_of_scan_line?","riegl.end_of_sca'
    + 'n_line?","riegl.source_indicator?","riegl.fwa?","riegl.waveform_availa'
    + 'ble?","riegl.wfm_sbl_id?","riegl.wfm_echo_time_offset?","riegl.extinct'
    + 'ion?","riegl.svb_amplitude_volumetric?","riegl.svb_surface?","riegl.sv'
    + 'b_bottom?","riegl.svb_path_length?"],"metadata":["riegl.atmosphere","r'
    + 'iegl.beam_geometry","riegl.device_geometry","riegl.device","riegl.gaus'
    + 'sian_decomposition?","riegl.exponential_decomposition?","riegl.mta_set'
    + 'tings?","riegl.near_range_correction?","riegl.noise_estimates?","riegl'
    + '.angular_notch_filter?","riegl.notch_filter?","riegl.pointcloud_info?"'
    + ',"riegl.pulse_position_modulation?","riegl.range_statistics?","riegl.r'
    + 'eceiver_internals?","riegl.reflectance_calculation?","riegl.reflectanc'
    + 'e_correction?","riegl.scan_pattern","riegl.time_base","riegl.window_an'
    + 'alysis?","riegl.window_echo_correction?"],"extension":"sdcx"}'
  );

// Schema for ".sidx" files
const
  RDB_SCHEMA_RIEGL_SIDX : System.String = (''
    + '{"identifier":"sidx","attributes":["riegl.id","riegl.shot_timestamp_hr'
    + '*","riegl.echo_first","riegl.echo_count"],"metadata":["riegl.shot_info'
    + '","riegl.echo_info"],"extension":"sidx"}'
  );

// Schema for ".sodx" files
const
  RDB_SCHEMA_RIEGL_SODX : System.String = (''
    + '{"identifier":"sodx","attributes":["riegl.id","riegl.shot_timestamp_hr'
    + '*","riegl.mirror_facet","riegl.scan_segment","riegl.start_of_scan_line'
    + '","riegl.line_angle_coarse","riegl.shot_origin","riegl.shot_biaxial_sh'
    + 'ift?","riegl.shot_direction","riegl.shot_direction_levelled?","riegl.w'
    + 'fm_sbl_first?","riegl.wfm_sbl_count?","riegl.echo_first?","riegl.echo_'
    + 'count?"],"metadata":["riegl.atmosphere","riegl.device","riegl.device_g'
    + 'eometry","riegl.device_output_limits","riegl.beam_geometry","riegl.nea'
    + 'r_range_correction?","riegl.window_echo_correction?","riegl.receiver_i'
    + 'nternals?","riegl.gaussian_decomposition?","riegl.exponential_decompos'
    + 'ition?","riegl.mta_settings?","riegl.pulse_position_modulation?","rieg'
    + 'l.notch_filter?","riegl.reflectance_calculation?","riegl.scan_pattern"'
    + ',"riegl.time_base","riegl.waveform_info?","riegl.echo_info?"],"extensi'
    + 'on":"sodx"}'
  );

// Schema for ".sp{C}" files
const
  RDB_SCHEMA_RIEGL_SPC : System.String = (''
    + '{"identifier":"sp{C}","attributes":["riegl.id*","riegl.wfm_sample_valu'
    + 'e"],"metadata":[],"extension":"sp{C}"}'
  );

// Schema for ".vtx" files
const
  RDB_SCHEMA_RIEGL_VTX : System.String = (''
    + '{"identifier":"vtx","attributes":["riegl.id*","riegl.xyz","riegl.xyz_a'
    + 'ccuracies?"],"metadata":["riegl.geo_tag"],"extension":"vtx"}'
  );

// Schema for ".vxls" files
const
  RDB_SCHEMA_RIEGL_VXLS : System.String = (''
    + '{"identifier":"vxls","attributes":["riegl.id","riegl.xyz*","riegl.cova'
    + 'riances","riegl.pca_axis_max","riegl.pca_axis_min","riegl.pca_extents"'
    + ',"riegl.point_count","riegl.reflectance","riegl.shape_id","riegl.voxel'
    + '_collapsed","riegl.std_dev?"],"metadata":["riegl.voxel_info","riegl.ge'
    + 'o_tag?"],"extension":"vxls"}'
  );

// Schema for ".wdcx" files
const
  RDB_SCHEMA_RIEGL_WDCX : System.String = (''
    + '{"identifier":"wdcx","attributes":["riegl.id","riegl.timestamp","riegl'
    + '.xyz*","riegl.xyz_socs","riegl.direction_medium?","riegl.direction?","'
    + 'riegl.amplitude","riegl.reflectance?","riegl.deviation?","riegl.pulse_'
    + 'width?","riegl.target_index","riegl.target_count","riegl.mirror_facet?'
    + '","riegl.scan_segment?","riegl.mta_uncertain_point?","riegl.mta_zone?"'
    + ',"riegl.window_echo_impact_corrected?","riegl.dyntrig_uncertain_point?'
    + '","riegl.rgba?","riegl.class?","riegl.start_of_scan_line?","riegl.end_'
    + 'of_scan_line?","riegl.source_indicator?","riegl.fwa?","riegl.waveform_'
    + 'available?","riegl.wfm_sbl_id?","riegl.wfm_echo_time_offset?","riegl.s'
    + 'can_angle","riegl.scan_direction","riegl.source_index?","riegl.scan_li'
    + 'ne_index?","riegl.shot_index_line?","riegl.hydro_intersection_point?",'
    + '"riegl.hydro_intersection_normal?","riegl.extinction?","riegl.svb_ampl'
    + 'itude_volumetric?","riegl.svb_surface?","riegl.svb_bottom?","riegl.svb'
    + '_path_length?"],"metadata":["riegl.atmosphere","riegl.beam_geometry","'
    + 'riegl.device_geometry","riegl.device","riegl.gaussian_decomposition?",'
    + '"riegl.exponential_decomposition?","riegl.geo_tag","riegl.georeferenci'
    + 'ng_parameters","riegl.mta_settings?","riegl.near_range_correction?","r'
    + 'iegl.noise_estimates?","riegl.angular_notch_filter?","riegl.notch_filt'
    + 'er?","riegl.pointcloud_info?","riegl.pulse_position_modulation?","rieg'
    + 'l.range_statistics?","riegl.receiver_internals?","riegl.reflectance_ca'
    + 'lculation?","riegl.reflectance_correction?","riegl.scan_pattern","rieg'
    + 'l.time_base","riegl.waveform_settings?","riegl.window_analysis?","rieg'
    + 'l.window_echo_correction?"],"extension":"wdcx"}'
  );

// Schema for ".wex" files
const
  RDB_SCHEMA_RIEGL_WEX : System.String = (''
    + '{"identifier":"wex","attributes":["riegl.id","riegl.timestamp*","riegl'
    + '.wex_filter_valid","riegl.wex_point_count","riegl.wex_amplitude","rieg'
    + 'l.wex_amplitude_std_dev","riegl.wex_amplitude_min","riegl.wex_amplitud'
    + 'e_max","riegl.wex_amplitude_offset","riegl.wex_deviation","riegl.wex_d'
    + 'eviation_std_dev","riegl.wex_deviation_min","riegl.wex_deviation_max",'
    + '"riegl.wex_range","riegl.wex_range_std_dev","riegl.wex_range_min","rie'
    + 'gl.wex_range_max","riegl.wex_filter_range_min","riegl.wex_filter_range'
    + '_max","riegl.wex_filter_amplitude_max"],"metadata":["riegl.device","ri'
    + 'egl.notch_filter","riegl.window_analysis"],"extension":"wex"}'
  );

// Table of all RDB file schema strings
const
  RDB_SCHEMA_ARRAY : array of System.String = nil; // filled during initialization

implementation

procedure FixStringEncoding;
begin
  // As the unit (.pas file) doesn't contain a BOM, we need to convert all strings
  // from UTF-8 to "native" encoding at runtime (tested on Delphi 7 and Delphi XE5)

  RDB_SCHEMA_RIEGL_AVG_FWA := String(UTF8ToAnsi(AnsiString(RDB_SCHEMA_RIEGL_AVG_FWA)));
  RDB_SCHEMA_RIEGL_AVG_SBX := String(UTF8ToAnsi(AnsiString(RDB_SCHEMA_RIEGL_AVG_SBX)));
  RDB_SCHEMA_RIEGL_AVG_SIDX := String(UTF8ToAnsi(AnsiString(RDB_SCHEMA_RIEGL_AVG_SIDX)));
  RDB_SCHEMA_RIEGL_AVG_SPC := String(UTF8ToAnsi(AnsiString(RDB_SCHEMA_RIEGL_AVG_SPC)));
  RDB_SCHEMA_RIEGL_CPX := String(UTF8ToAnsi(AnsiString(RDB_SCHEMA_RIEGL_CPX)));
  RDB_SCHEMA_RIEGL_DOIX := String(UTF8ToAnsi(AnsiString(RDB_SCHEMA_RIEGL_DOIX)));
  RDB_SCHEMA_RIEGL_EIFX := String(UTF8ToAnsi(AnsiString(RDB_SCHEMA_RIEGL_EIFX)));
  RDB_SCHEMA_RIEGL_EPFX := String(UTF8ToAnsi(AnsiString(RDB_SCHEMA_RIEGL_EPFX)));
  RDB_SCHEMA_RIEGL_FWA := String(UTF8ToAnsi(AnsiString(RDB_SCHEMA_RIEGL_FWA)));
  RDB_SCHEMA_RIEGL_LLHX := String(UTF8ToAnsi(AnsiString(RDB_SCHEMA_RIEGL_LLHX)));
  RDB_SCHEMA_RIEGL_MPX := String(UTF8ToAnsi(AnsiString(RDB_SCHEMA_RIEGL_MPX)));
  RDB_SCHEMA_RIEGL_MTCH := String(UTF8ToAnsi(AnsiString(RDB_SCHEMA_RIEGL_MTCH)));
  RDB_SCHEMA_RIEGL_MVX := String(UTF8ToAnsi(AnsiString(RDB_SCHEMA_RIEGL_MVX)));
  RDB_SCHEMA_RIEGL_OBSX := String(UTF8ToAnsi(AnsiString(RDB_SCHEMA_RIEGL_OBSX)));
  RDB_SCHEMA_RIEGL_OPEFX := String(UTF8ToAnsi(AnsiString(RDB_SCHEMA_RIEGL_OPEFX)));
  RDB_SCHEMA_RIEGL_OPP := String(UTF8ToAnsi(AnsiString(RDB_SCHEMA_RIEGL_OPP)));
  RDB_SCHEMA_RIEGL_OPX := String(UTF8ToAnsi(AnsiString(RDB_SCHEMA_RIEGL_OPX)));
  RDB_SCHEMA_RIEGL_OWP := String(UTF8ToAnsi(AnsiString(RDB_SCHEMA_RIEGL_OWP)));
  RDB_SCHEMA_RIEGL_PEFX := String(UTF8ToAnsi(AnsiString(RDB_SCHEMA_RIEGL_PEFX)));
  RDB_SCHEMA_RIEGL_PROJECT_POFX := String(UTF8ToAnsi(AnsiString(RDB_SCHEMA_RIEGL_PROJECT_POFX)));
  RDB_SCHEMA_RIEGL_SCAN_POFX := String(UTF8ToAnsi(AnsiString(RDB_SCHEMA_RIEGL_SCAN_POFX)));
  RDB_SCHEMA_RIEGL_PROJECT_POQX := String(UTF8ToAnsi(AnsiString(RDB_SCHEMA_RIEGL_PROJECT_POQX)));
  RDB_SCHEMA_RIEGL_SCAN_POQX := String(UTF8ToAnsi(AnsiString(RDB_SCHEMA_RIEGL_SCAN_POQX)));
  RDB_SCHEMA_RIEGL_PPX := String(UTF8ToAnsi(AnsiString(RDB_SCHEMA_RIEGL_PPX)));
  RDB_SCHEMA_RIEGL_PROJECT_PTCH := String(UTF8ToAnsi(AnsiString(RDB_SCHEMA_RIEGL_PROJECT_PTCH)));
  RDB_SCHEMA_RIEGL_SCAN_PTCH := String(UTF8ToAnsi(AnsiString(RDB_SCHEMA_RIEGL_SCAN_PTCH)));
  RDB_SCHEMA_RIEGL_SCANPOS_PTCH := String(UTF8ToAnsi(AnsiString(RDB_SCHEMA_RIEGL_SCANPOS_PTCH)));
  RDB_SCHEMA_RIEGL_RDBX := String(UTF8ToAnsi(AnsiString(RDB_SCHEMA_RIEGL_RDBX)));
  RDB_SCHEMA_RIEGL_RMVX := String(UTF8ToAnsi(AnsiString(RDB_SCHEMA_RIEGL_RMVX)));
  RDB_SCHEMA_RIEGL_S10X := String(UTF8ToAnsi(AnsiString(RDB_SCHEMA_RIEGL_S10X)));
  RDB_SCHEMA_RIEGL_SBX := String(UTF8ToAnsi(AnsiString(RDB_SCHEMA_RIEGL_SBX)));
  RDB_SCHEMA_RIEGL_SDCX := String(UTF8ToAnsi(AnsiString(RDB_SCHEMA_RIEGL_SDCX)));
  RDB_SCHEMA_RIEGL_SIDX := String(UTF8ToAnsi(AnsiString(RDB_SCHEMA_RIEGL_SIDX)));
  RDB_SCHEMA_RIEGL_SODX := String(UTF8ToAnsi(AnsiString(RDB_SCHEMA_RIEGL_SODX)));
  RDB_SCHEMA_RIEGL_SPC := String(UTF8ToAnsi(AnsiString(RDB_SCHEMA_RIEGL_SPC)));
  RDB_SCHEMA_RIEGL_VTX := String(UTF8ToAnsi(AnsiString(RDB_SCHEMA_RIEGL_VTX)));
  RDB_SCHEMA_RIEGL_VXLS := String(UTF8ToAnsi(AnsiString(RDB_SCHEMA_RIEGL_VXLS)));
  RDB_SCHEMA_RIEGL_WDCX := String(UTF8ToAnsi(AnsiString(RDB_SCHEMA_RIEGL_WDCX)));
  RDB_SCHEMA_RIEGL_WEX := String(UTF8ToAnsi(AnsiString(RDB_SCHEMA_RIEGL_WEX)));
end;

procedure FillSchemaArray;
var
  i : Integer;
begin
  SetLength(RDB_SCHEMA_ARRAY, 39); i := -1;
  Inc(i); RDB_SCHEMA_ARRAY[i] := RDB_SCHEMA_RIEGL_AVG_FWA;
  Inc(i); RDB_SCHEMA_ARRAY[i] := RDB_SCHEMA_RIEGL_AVG_SBX;
  Inc(i); RDB_SCHEMA_ARRAY[i] := RDB_SCHEMA_RIEGL_AVG_SIDX;
  Inc(i); RDB_SCHEMA_ARRAY[i] := RDB_SCHEMA_RIEGL_AVG_SPC;
  Inc(i); RDB_SCHEMA_ARRAY[i] := RDB_SCHEMA_RIEGL_CPX;
  Inc(i); RDB_SCHEMA_ARRAY[i] := RDB_SCHEMA_RIEGL_DOIX;
  Inc(i); RDB_SCHEMA_ARRAY[i] := RDB_SCHEMA_RIEGL_EIFX;
  Inc(i); RDB_SCHEMA_ARRAY[i] := RDB_SCHEMA_RIEGL_EPFX;
  Inc(i); RDB_SCHEMA_ARRAY[i] := RDB_SCHEMA_RIEGL_FWA;
  Inc(i); RDB_SCHEMA_ARRAY[i] := RDB_SCHEMA_RIEGL_LLHX;
  Inc(i); RDB_SCHEMA_ARRAY[i] := RDB_SCHEMA_RIEGL_MPX;
  Inc(i); RDB_SCHEMA_ARRAY[i] := RDB_SCHEMA_RIEGL_MTCH;
  Inc(i); RDB_SCHEMA_ARRAY[i] := RDB_SCHEMA_RIEGL_MVX;
  Inc(i); RDB_SCHEMA_ARRAY[i] := RDB_SCHEMA_RIEGL_OBSX;
  Inc(i); RDB_SCHEMA_ARRAY[i] := RDB_SCHEMA_RIEGL_OPEFX;
  Inc(i); RDB_SCHEMA_ARRAY[i] := RDB_SCHEMA_RIEGL_OPP;
  Inc(i); RDB_SCHEMA_ARRAY[i] := RDB_SCHEMA_RIEGL_OPX;
  Inc(i); RDB_SCHEMA_ARRAY[i] := RDB_SCHEMA_RIEGL_OWP;
  Inc(i); RDB_SCHEMA_ARRAY[i] := RDB_SCHEMA_RIEGL_PEFX;
  Inc(i); RDB_SCHEMA_ARRAY[i] := RDB_SCHEMA_RIEGL_PROJECT_POFX;
  Inc(i); RDB_SCHEMA_ARRAY[i] := RDB_SCHEMA_RIEGL_SCAN_POFX;
  Inc(i); RDB_SCHEMA_ARRAY[i] := RDB_SCHEMA_RIEGL_PROJECT_POQX;
  Inc(i); RDB_SCHEMA_ARRAY[i] := RDB_SCHEMA_RIEGL_SCAN_POQX;
  Inc(i); RDB_SCHEMA_ARRAY[i] := RDB_SCHEMA_RIEGL_PPX;
  Inc(i); RDB_SCHEMA_ARRAY[i] := RDB_SCHEMA_RIEGL_PROJECT_PTCH;
  Inc(i); RDB_SCHEMA_ARRAY[i] := RDB_SCHEMA_RIEGL_SCAN_PTCH;
  Inc(i); RDB_SCHEMA_ARRAY[i] := RDB_SCHEMA_RIEGL_SCANPOS_PTCH;
  Inc(i); RDB_SCHEMA_ARRAY[i] := RDB_SCHEMA_RIEGL_RDBX;
  Inc(i); RDB_SCHEMA_ARRAY[i] := RDB_SCHEMA_RIEGL_RMVX;
  Inc(i); RDB_SCHEMA_ARRAY[i] := RDB_SCHEMA_RIEGL_S10X;
  Inc(i); RDB_SCHEMA_ARRAY[i] := RDB_SCHEMA_RIEGL_SBX;
  Inc(i); RDB_SCHEMA_ARRAY[i] := RDB_SCHEMA_RIEGL_SDCX;
  Inc(i); RDB_SCHEMA_ARRAY[i] := RDB_SCHEMA_RIEGL_SIDX;
  Inc(i); RDB_SCHEMA_ARRAY[i] := RDB_SCHEMA_RIEGL_SODX;
  Inc(i); RDB_SCHEMA_ARRAY[i] := RDB_SCHEMA_RIEGL_SPC;
  Inc(i); RDB_SCHEMA_ARRAY[i] := RDB_SCHEMA_RIEGL_VTX;
  Inc(i); RDB_SCHEMA_ARRAY[i] := RDB_SCHEMA_RIEGL_VXLS;
  Inc(i); RDB_SCHEMA_ARRAY[i] := RDB_SCHEMA_RIEGL_WDCX;
  Inc(i); RDB_SCHEMA_ARRAY[i] := RDB_SCHEMA_RIEGL_WEX;
end;

initialization

FixStringEncoding;
FillSchemaArray;

end.
